@@ -26,7 +26,9 @@ import time
 import kissen
 import pygame
 import random
+#from PyQt4.phonon import Phonon
 #import logging
+import webbrowser
 import subprocess
 from PyQt4 import QtGui
 from PyQt4.uic import loadUi
@@ -67,7 +69,7 @@ class MainWindow(QtGui.QMainWindow):
         self.ui.minimize.clicked.connect(self.minimize2)
         self.ui.idea.clicked.connect(self.idea2)
         self.ui.about.clicked.connect(self.about2)
-        
+        self.ui.craveo.clicked.connect(self.craveobrowser)
         #Methoden
        
     def fartrandom(self):#Zufallsmechanismus für Abspielen der Furzsounds 10-81 
@@ -90,7 +92,9 @@ class MainWindow(QtGui.QMainWindow):
                  "Click me, in order to let me fart.\n"
                  "I can do more than 65 different\n"
                  "kind of fart sounds\n"
-                 "Version: 0.0.8\n")
+                 "Version: 0.0.9\n")
+    def craveobrowser(self):
+        webbrowser.open("http://www.craveo.de")
         
     def about2(self):
         QtGui.QMessageBox.aboutQt(self)    
